@@ -39,13 +39,13 @@ def _get_uri(key=None):
     port = read_secret(cate1='notecoin', cate2='dataset', cate3='mysql', cate4='port') or '3306'
     user = read_secret(cate1='notecoin', cate2='dataset', cate3='mysql', cate4='user')
     password = read_secret(cate1='notecoin', cate2='dataset', cate3='mysql', cate4='password')
-    db_name = 'notecoin' if key is None or len(key) == 0 else f'notecoin_{key}'
+    db_name = 'notecoin' if key is None or len(key) == 0 else f'notecoin_{key.lower()}'
     create_database(db_name)
     return f"mysql+pymysql://{user}:{password}@{host}:{port}/{db_name}?charset=utf8"
 
 
 def _init_engine_meta(key=None):
-    engine = create_engine(_get_uri())
+    engine = create_engine(_get_uri(key=key))
     engine_dict[key] = engine
     meta_dict[key] = MetaData(bind=engine)
 
